@@ -275,28 +275,20 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 34:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_resize_set(&current_match, result, get_long("width"), get_long("height"));
+             cmd_resize_set(&current_match, result, get_long("width"), get_string("mode_width"), get_long("height"), get_string("mode_height"));
 #else
-           fprintf(stderr, "cmd_resize_set(%ld, %ld)\n", get_long("width"), get_long("height"));
+           fprintf(stderr, "cmd_resize_set(%ld, %s, %ld, %s)\n", get_long("width"), get_string("mode_width"), get_long("height"), get_string("mode_height"));
 #endif
              break;
          case 35:
              result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_resize_set(&current_match, result, get_long("width"), get_long("height"));
-#else
-           fprintf(stderr, "cmd_resize_set(%ld, %ld)\n", get_long("width"), get_long("height"));
-#endif
-             break;
-         case 36:
-             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_resize(&current_match, result, get_string("way"), get_string("direction"), get_long("resize_px"), 10);
 #else
            fprintf(stderr, "cmd_resize(%s, %s, %ld, %d)\n", get_string("way"), get_string("direction"), get_long("resize_px"), 10);
 #endif
              break;
-         case 37:
+         case 36:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_swap(&current_match, result, get_string("mode"), get_string("arg"));
@@ -304,7 +296,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_swap(%s, %s)\n", get_string("mode"), get_string("arg"));
 #endif
              break;
-         case 38:
+         case 37:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_border(&current_match, result, get_string("border_style"), 2);
@@ -312,7 +304,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 2);
 #endif
              break;
-         case 39:
+         case 38:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_border(&current_match, result, get_string("border_style"), get_long("border_width"));
@@ -320,7 +312,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_border(%s, %ld)\n", get_string("border_style"), get_long("border_width"));
 #endif
              break;
-         case 40:
+         case 39:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_focus_output(&current_match, result, get_string("output"));
@@ -328,7 +320,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_focus_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 41:
+         case 40:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_con_to_mark(&current_match, result, get_string("mark"));
@@ -336,7 +328,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_move_con_to_mark(%s)\n", get_string("mark"));
 #endif
              break;
-         case 42:
+         case 41:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_title_format(&current_match, result, get_string("format"));
@@ -344,7 +336,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_title_format(%s)\n", get_string("format"));
 #endif
              break;
-         case 43:
+         case 42:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_fullscreen(&current_match, result, get_string("action"), "output");
@@ -352,7 +344,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_fullscreen(%s, %s)\n", get_string("action"), "output");
 #endif
              break;
-         case 44:
+         case 43:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_scratchpad_show(&current_match, result);
@@ -360,12 +352,20 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_scratchpad_show()\n");
 #endif
              break;
-         case 45:
+         case 44:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_resize(&current_match, result, get_string("way"), get_string("direction"), 10, 10);
 #else
            fprintf(stderr, "cmd_resize(%s, %s, %d, %d)\n", get_string("way"), get_string("direction"), 10, 10);
+#endif
+             break;
+         case 45:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_workspace(&current_match, result, get_string("direction"));
+#else
+           fprintf(stderr, "cmd_workspace(%s)\n", get_string("direction"));
 #endif
              break;
          case 46:
@@ -394,21 +394,13 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 49:
              result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_workspace(&current_match, result, get_string("direction"));
-#else
-           fprintf(stderr, "cmd_workspace(%s)\n", get_string("direction"));
-#endif
-             break;
-         case 50:
-             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_workspace_back_and_forth(&current_match, result);
 #else
            fprintf(stderr, "cmd_workspace_back_and_forth()\n");
 #endif
              break;
-         case 51:
+         case 50:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_workspace_name(&current_match, result, get_string("workspace"), get_string("no_auto_back_and_forth"));
@@ -416,12 +408,20 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_workspace_name(%s, %s)\n", get_string("workspace"), get_string("no_auto_back_and_forth"));
 #endif
              break;
-         case 52:
+         case 51:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_bar(&current_match, result, get_string("bar_type"), get_string("bar_value"), get_string("bar_id"));
 #else
            fprintf(stderr, "cmd_bar(%s, %s, %s)\n", get_string("bar_type"), get_string("bar_value"), get_string("bar_id"));
+#endif
+             break;
+         case 52:
+             result->next_state = CRITERIA;
+#ifndef TEST_PARSER
+             cmd_criteria_add(&current_match, result, get_string("ctype"), NULL);
+#else
+           fprintf(stderr, "cmd_criteria_add(%s, NULL)\n", get_string("ctype"));
 #endif
              break;
          case 53:
@@ -433,19 +433,19 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
 #endif
              break;
          case 54:
-             result->next_state = CRITERIA;
-#ifndef TEST_PARSER
-             cmd_criteria_add(&current_match, result, get_string("ctype"), NULL);
-#else
-           fprintf(stderr, "cmd_criteria_add(%s, NULL)\n", get_string("ctype"));
-#endif
-             break;
-         case 55:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_criteria_match_windows(&current_match, result);
 #else
            fprintf(stderr, "cmd_criteria_match_windows()\n");
+#endif
+             break;
+         case 55:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_debuglog(&current_match, result, get_string("argument"));
+#else
+           fprintf(stderr, "cmd_debuglog(%s)\n", get_string("argument"));
 #endif
              break;
          case 56:
@@ -467,9 +467,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 58:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_debuglog(&current_match, result, get_string("argument"));
+             cmd_floating(&current_match, result, get_string("floating"));
 #else
-           fprintf(stderr, "cmd_debuglog(%s)\n", get_string("argument"));
+           fprintf(stderr, "cmd_floating(%s)\n", get_string("floating"));
 #endif
              break;
          case 59:
@@ -489,14 +489,6 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
 #endif
              break;
          case 61:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_floating(&current_match, result, get_string("floating"));
-#else
-           fprintf(stderr, "cmd_floating(%s)\n", get_string("floating"));
-#endif
-             break;
-         case 62:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cmd_criteria_init(&current_match, result);
@@ -504,7 +496,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_criteria_init()\n");
 #endif
              break;
-         case 63:
+         case 62:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_exit(&current_match, result);
@@ -512,7 +504,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_exit()\n");
 #endif
              break;
-         case 64:
+         case 63:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_restart(&current_match, result);
@@ -520,7 +512,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_restart()\n");
 #endif
              break;
-         case 65:
+         case 64:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_reload(&current_match, result);
@@ -528,12 +520,20 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_reload()\n");
 #endif
              break;
-         case 66:
+         case 65:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_open(&current_match, result);
 #else
            fprintf(stderr, "cmd_open()\n");
+#endif
+             break;
+         case 66:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cmd_border(&current_match, result, get_string("border_style"), 0);
+#else
+           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 0);
 #endif
              break;
          case 67:
@@ -547,17 +547,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 68:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_border(&current_match, result, get_string("border_style"), 0);
+             cmd_border(&current_match, result, get_string("border_style"), 1);
 #else
-           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 0);
+           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 1);
 #endif
              break;
          case 69:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_border(&current_match, result, get_string("border_style"), 1);
+             cmd_layout(&current_match, result, get_string("layout_mode"));
 #else
-           fprintf(stderr, "cmd_border(%s, %d)\n", get_string("border_style"), 1);
+           fprintf(stderr, "cmd_layout(%s)\n", get_string("layout_mode"));
 #endif
              break;
          case 70:
@@ -603,17 +603,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 75:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_layout(&current_match, result, get_string("layout_mode"));
+             cmd_shmlog(&current_match, result, get_string("argument"));
 #else
-           fprintf(stderr, "cmd_layout(%s)\n", get_string("layout_mode"));
+           fprintf(stderr, "cmd_shmlog(%s)\n", get_string("argument"));
 #endif
              break;
          case 76:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_shmlog(&current_match, result, get_string("argument"));
+             cmd_sticky(&current_match, result, get_string("action"));
 #else
-           fprintf(stderr, "cmd_shmlog(%s)\n", get_string("argument"));
+           fprintf(stderr, "cmd_sticky(%s)\n", get_string("action"));
 #endif
              break;
          case 77:
@@ -635,9 +635,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 79:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_sticky(&current_match, result, get_string("action"));
+             cmd_unmark(&current_match, result, get_string("mark"));
 #else
-           fprintf(stderr, "cmd_sticky(%s)\n", get_string("action"));
+           fprintf(stderr, "cmd_unmark(%s)\n", get_string("mark"));
 #endif
              break;
          case 80:
@@ -651,9 +651,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 81:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_unmark(&current_match, result, get_string("mark"));
+             cmd_focus_direction(&current_match, result, get_string("direction"));
 #else
-           fprintf(stderr, "cmd_unmark(%s)\n", get_string("mark"));
+           fprintf(stderr, "cmd_focus_direction(%s)\n", get_string("direction"));
 #endif
              break;
          case 82:
@@ -683,9 +683,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 85:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus_direction(&current_match, result, get_string("direction"));
+             cmd_focus_window_mode(&current_match, result, get_string("window_mode"));
 #else
-           fprintf(stderr, "cmd_focus_direction(%s)\n", get_string("direction"));
+           fprintf(stderr, "cmd_focus_window_mode(%s)\n", get_string("window_mode"));
 #endif
              break;
          case 86:
@@ -707,9 +707,9 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 88:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus_window_mode(&current_match, result, get_string("window_mode"));
+             cmd_focus_level(&current_match, result, get_string("level"));
 #else
-           fprintf(stderr, "cmd_focus_window_mode(%s)\n", get_string("window_mode"));
+           fprintf(stderr, "cmd_focus_level(%s)\n", get_string("level"));
 #endif
              break;
          case 89:
@@ -723,17 +723,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 90:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus_level(&current_match, result, get_string("level"));
+             cmd_focus(&current_match, result);
 #else
-           fprintf(stderr, "cmd_focus_level(%s)\n", get_string("level"));
+           fprintf(stderr, "cmd_focus()\n");
 #endif
              break;
          case 91:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_focus(&current_match, result);
+             cmd_split(&current_match, result, get_string("direction"));
 #else
-           fprintf(stderr, "cmd_focus()\n");
+           fprintf(stderr, "cmd_split(%s)\n", get_string("direction"));
 #endif
              break;
          case 92:
@@ -779,17 +779,17 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
          case 97:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_split(&current_match, result, get_string("direction"));
+             cmd_exec(&current_match, result, get_string("nosn"), get_string("command"));
 #else
-           fprintf(stderr, "cmd_split(%s)\n", get_string("direction"));
+           fprintf(stderr, "cmd_exec(%s, %s)\n", get_string("nosn"), get_string("command"));
 #endif
              break;
          case 98:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cmd_exec(&current_match, result, get_string("nosn"), get_string("command"));
+             cmd_kill(&current_match, result, get_string("kill_mode"));
 #else
-           fprintf(stderr, "cmd_exec(%s, %s)\n", get_string("nosn"), get_string("command"));
+           fprintf(stderr, "cmd_kill(%s)\n", get_string("kill_mode"));
 #endif
              break;
          case 99:
@@ -810,21 +810,13 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
              break;
          case 101:
              result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cmd_kill(&current_match, result, get_string("kill_mode"));
-#else
-           fprintf(stderr, "cmd_kill(%s)\n", get_string("kill_mode"));
-#endif
-             break;
-         case 102:
-             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_mark(&current_match, result, get_string("mark"), get_string("mode"), get_string("toggle"));
 #else
            fprintf(stderr, "cmd_mark(%s, %s, %s)\n", get_string("mark"), get_string("mode"), get_string("toggle"));
 #endif
              break;
-         case 103:
+         case 102:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_mode(&current_match, result, get_string("mode"));
@@ -832,7 +824,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_mode(%s)\n", get_string("mode"));
 #endif
              break;
-         case 104:
+         case 103:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_move_scratchpad(&current_match, result);
@@ -840,7 +832,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_move_scratchpad()\n");
 #endif
              break;
-         case 105:
+         case 104:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_nop(&current_match, result, get_string("comment"));
@@ -848,7 +840,7 @@ static void GENERATED_call(const int call_identifier, struct CommandResultIR *re
            fprintf(stderr, "cmd_nop(%s)\n", get_string("comment"));
 #endif
              break;
-         case 106:
+         case 105:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cmd_nop(&current_match, result, NULL);
