@@ -51,25 +51,25 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 6:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_workspace_back_and_forth(&current_match, result, get_string("value"));
+             cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), get_long("width"));
 #else
-           fprintf(stderr, "cfg_workspace_back_and_forth(%s)\n", get_string("value"));
+           fprintf(stderr, "cfg_default_border(%s, %s, %ld)\n", get_string("windowtype"), get_string("border"), get_long("width"));
 #endif
              break;
          case 7:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_popup_during_fullscreen(&current_match, result, get_string("value"));
+             cfg_workspace_back_and_forth(&current_match, result, get_string("value"));
 #else
-           fprintf(stderr, "cfg_popup_during_fullscreen(%s)\n", get_string("value"));
+           fprintf(stderr, "cfg_workspace_back_and_forth(%s)\n", get_string("value"));
 #endif
              break;
          case 8:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_popup_during_fullscreen(&current_match, result, get_string("value"));
+             cfg_assign(&current_match, result, get_string("number"), 1);
 #else
-           fprintf(stderr, "cfg_popup_during_fullscreen(%s)\n", get_string("value"));
+           fprintf(stderr, "cfg_assign(%s, %d)\n", get_string("number"), 1);
 #endif
              break;
          case 9:
@@ -81,6 +81,22 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 10:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_popup_during_fullscreen(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_popup_during_fullscreen(%s)\n", get_string("value"));
+#endif
+             break;
+         case 11:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_popup_during_fullscreen(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_popup_during_fullscreen(%s)\n", get_string("value"));
+#endif
+             break;
+         case 12:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_workspace_buttons(&current_match, result, get_string("value"));
@@ -88,7 +104,15 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_workspace_buttons(%s)\n", get_string("value"));
 #endif
              break;
-         case 11:
+         case 13:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), 2);
+#else
+           fprintf(stderr, "cfg_default_border(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), 2);
+#endif
+             break;
+         case 14:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_separator_symbol(&current_match, result, get_string("separator"));
@@ -96,7 +120,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_separator_symbol(%s)\n", get_string("separator"));
 #endif
              break;
-         case 12:
+         case 15:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_force_focus_wrapping(&current_match, result, get_string("value"));
@@ -104,15 +128,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_force_focus_wrapping(%s)\n", get_string("value"));
 #endif
              break;
-         case 13:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_new_window(&current_match, result, get_string("windowtype"), get_string("border"), get_long("width"));
-#else
-           fprintf(stderr, "cfg_new_window(%s, %s, %ld)\n", get_string("windowtype"), get_string("border"), get_long("width"));
-#endif
-             break;
-         case 14:
+         case 16:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_workspace(&current_match, result, get_string("workspace"), get_string("output"));
@@ -120,36 +136,20 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_workspace(%s, %s)\n", get_string("workspace"), get_string("output"));
 #endif
              break;
-         case 15:
+         case 17:
              result->next_state = BAR;
 #ifndef TEST_PARSER
-             cfg_bar_bindsym(&current_match, result, get_string("button"), get_string("command"));
+             cfg_bar_bindsym(&current_match, result, get_string("button"), get_string("release"), get_string("command"));
 #else
-           fprintf(stderr, "cfg_bar_bindsym(%s, %s)\n", get_string("button"), get_string("command"));
+           fprintf(stderr, "cfg_bar_bindsym(%s, %s, %s)\n", get_string("button"), get_string("release"), get_string("command"));
 #endif
              break;
-         case 16:
+         case 18:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_tray_padding(&current_match, result, get_long("padding_px"));
 #else
            fprintf(stderr, "cfg_bar_tray_padding(%ld)\n", get_long("padding_px"));
-#endif
-             break;
-         case 17:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_default_orientation(&current_match, result, get_string("orientation"));
-#else
-           fprintf(stderr, "cfg_default_orientation(%s)\n", get_string("orientation"));
-#endif
-             break;
-         case 18:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_default_orientation(&current_match, result, get_string("orientation"));
-#else
-           fprintf(stderr, "cfg_default_orientation(%s)\n", get_string("orientation"));
 #endif
              break;
          case 19:
@@ -162,13 +162,29 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 20:
              result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_default_orientation(&current_match, result, get_string("orientation"));
+#else
+           fprintf(stderr, "cfg_default_orientation(%s)\n", get_string("orientation"));
+#endif
+             break;
+         case 21:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_default_orientation(&current_match, result, get_string("orientation"));
+#else
+           fprintf(stderr, "cfg_default_orientation(%s)\n", get_string("orientation"));
+#endif
+             break;
+         case 22:
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_focus_follows_mouse(&current_match, result, get_string("value"));
 #else
            fprintf(stderr, "cfg_focus_follows_mouse(%s)\n", get_string("value"));
 #endif
              break;
-         case 21:
+         case 23:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_status_command(&current_match, result, get_string("command"));
@@ -176,7 +192,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_status_command(%s)\n", get_string("command"));
 #endif
              break;
-         case 22:
+         case 24:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_wheel_down_cmd(&current_match, result, get_string("command"));
@@ -184,7 +200,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_wheel_down_cmd(%s)\n", get_string("command"));
 #endif
              break;
-         case 23:
+         case 25:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"), get_string("child_border"));
@@ -192,7 +208,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color(%s, %s, %s, %s, %s, %s)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"), get_string("child_border"));
 #endif
              break;
-         case 24:
+         case 26:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"), NULL);
@@ -200,7 +216,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color(%s, %s, %s, %s, %s, NULL)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), get_string("indicator"));
 #endif
              break;
-         case 25:
+         case 27:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_for_window(&current_match, result, get_string("command"));
@@ -208,7 +224,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_for_window(%s)\n", get_string("command"));
 #endif
              break;
-         case 26:
+         case 28:
              result->next_state = BAR_COLORS;
 #ifndef TEST_PARSER
              cfg_bar_color_single(&current_match, result, get_string("colorclass"), get_string("color"));
@@ -216,28 +232,12 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_color_single(%s, %s)\n", get_string("colorclass"), get_string("color"));
 #endif
              break;
-         case 27:
+         case 29:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_floating_modifier(&current_match, result, get_string("modifiers"));
 #else
            fprintf(stderr, "cfg_floating_modifier(%s)\n", get_string("modifiers"));
-#endif
-             break;
-         case 28:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_hide_edge_borders(&current_match, result, get_string("hide_borders"));
-#else
-           fprintf(stderr, "cfg_hide_edge_borders(%s)\n", get_string("hide_borders"));
-#endif
-             break;
-         case 29:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_hide_edge_borders(&current_match, result, get_string("hide_borders"));
-#else
-           fprintf(stderr, "cfg_hide_edge_borders(%s)\n", get_string("hide_borders"));
 #endif
              break;
          case 30:
@@ -315,25 +315,25 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
          case 39:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_new_window(&current_match, result, get_string("windowtype"), get_string("border"), 2);
+             cfg_hide_edge_borders(&current_match, result, get_string("hide_borders"));
 #else
-           fprintf(stderr, "cfg_new_window(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), 2);
+           fprintf(stderr, "cfg_hide_edge_borders(%s)\n", get_string("hide_borders"));
 #endif
              break;
          case 40:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_assign(&current_match, result, get_string("workspace"));
+             cfg_hide_edge_borders(&current_match, result, get_string("hide_borders"));
 #else
-           fprintf(stderr, "cfg_assign(%s)\n", get_string("workspace"));
+           fprintf(stderr, "cfg_hide_edge_borders(%s)\n", get_string("hide_borders"));
 #endif
              break;
          case 41:
-             result->next_state = BAR;
+             result->next_state = INITIAL;
 #ifndef TEST_PARSER
-             cfg_bar_hidden_state(&current_match, result, get_string("hidden_state"));
+             cfg_assign(&current_match, result, get_string("workspace"), 0);
 #else
-           fprintf(stderr, "cfg_bar_hidden_state(%s)\n", get_string("hidden_state"));
+           fprintf(stderr, "cfg_assign(%s, %d)\n", get_string("workspace"), 0);
 #endif
              break;
          case 42:
@@ -346,26 +346,26 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
              break;
          case 43:
              result->next_state = BAR;
+#ifndef TEST_PARSER
+             cfg_bar_hidden_state(&current_match, result, get_string("hidden_state"));
+#else
+           fprintf(stderr, "cfg_bar_hidden_state(%s)\n", get_string("hidden_state"));
+#endif
+             break;
+         case 44:
+             result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_wheel_up_cmd(&current_match, result, get_string("command"));
 #else
            fprintf(stderr, "cfg_bar_wheel_up_cmd(%s)\n", get_string("command"));
 #endif
              break;
-         case 44:
+         case 45:
              result->next_state = MODE;
 #ifndef TEST_PARSER
              cfg_mode_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #else
            fprintf(stderr, "cfg_mode_binding(%s, %s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
-#endif
-             break;
-         case 45:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_workspace_layout(&current_match, result, get_string("layout"));
-#else
-           fprintf(stderr, "cfg_workspace_layout(%s)\n", get_string("layout"));
 #endif
              break;
          case 46:
@@ -393,6 +393,14 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
 #endif
              break;
          case 49:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_workspace_layout(&current_match, result, get_string("layout"));
+#else
+           fprintf(stderr, "cfg_workspace_layout(%s)\n", get_string("layout"));
+#endif
+             break;
+         case 50:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_i3bar_command(&current_match, result, get_string("command"));
@@ -400,7 +408,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_i3bar_command(%s)\n", get_string("command"));
 #endif
              break;
-         case 50:
+         case 51:
              result->next_state = BAR_COLORS;
 #ifndef TEST_PARSER
              cfg_bar_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), NULL);
@@ -408,7 +416,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_color(%s, %s, %s, NULL)\n", get_string("colorclass"), get_string("border"), get_string("background"));
 #endif
              break;
-         case 51:
+         case 52:
              result->next_state = BAR_COLORS;
 #ifndef TEST_PARSER
              cfg_bar_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"));
@@ -416,7 +424,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_color(%s, %s, %s, %s)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"));
 #endif
              break;
-         case 52:
+         case 53:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_socket_path(&current_match, result, get_string("path"));
@@ -424,7 +432,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_socket_path(%s)\n", get_string("path"));
 #endif
              break;
-         case 53:
+         case 54:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_tray_output(&current_match, result, get_string("output"));
@@ -432,7 +440,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_tray_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 54:
+         case 55:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color(&current_match, result, get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"), NULL, NULL);
@@ -440,7 +448,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color(%s, %s, %s, %s, NULL, NULL)\n", get_string("colorclass"), get_string("border"), get_string("background"), get_string("text"));
 #endif
              break;
-         case 55:
+         case 56:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_disable_randr15(&current_match, result, get_string("value"));
@@ -448,7 +456,127 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_disable_randr15(%s)\n", get_string("value"));
 #endif
              break;
-         case 56:
+         case 57:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), -1);
+#else
+           fprintf(stderr, "cfg_default_border(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
+#endif
+             break;
+         case 58:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_default_border(&current_match, result, get_string("windowtype"), get_string("border"), -1);
+#else
+           fprintf(stderr, "cfg_default_border(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
+#endif
+             break;
+         case 59:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 60:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 61:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 62:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 63:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 64:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 65:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 66:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 67:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 68:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 69:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 70:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 71:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_focus_wrapping(&current_match, result, get_string("value"));
+#else
+           fprintf(stderr, "cfg_focus_wrapping(%s)\n", get_string("value"));
+#endif
+             break;
+         case 72:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_force_xinerama(&current_match, result, get_string("value"));
@@ -456,7 +584,15 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_force_xinerama(%s)\n", get_string("value"));
 #endif
              break;
-         case 57:
+         case 73:
+             result->next_state = INITIAL;
+#ifndef TEST_PARSER
+             cfg_assign_output(&current_match, result, get_string("output"));
+#else
+           fprintf(stderr, "cfg_assign_output(%s)\n", get_string("output"));
+#endif
+             break;
+         case 74:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
@@ -465,7 +601,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_add(&current_match, result, get_string("ctype"), get_string("cvalue"));
 #endif
              break;
-         case 58:
+         case 75:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_mouse_warping(&current_match, result, get_string("value"));
@@ -473,7 +609,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
 #endif
              break;
-         case 59:
+         case 76:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_mouse_warping(&current_match, result, get_string("value"));
@@ -481,7 +617,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_mouse_warping(%s)\n", get_string("value"));
 #endif
              break;
-         case 60:
+         case 77:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_restart_state(&current_match, result, get_string("path"));
@@ -489,7 +625,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_restart_state(%s)\n", get_string("path"));
 #endif
              break;
-         case 61:
+         case 78:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -497,7 +633,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 62:
+         case 79:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -505,7 +641,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 63:
+         case 80:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -513,7 +649,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 64:
+         case 81:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -521,7 +657,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 65:
+         case 82:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -529,7 +665,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 66:
+         case 83:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -537,7 +673,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 67:
+         case 84:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -545,7 +681,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 68:
+         case 85:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -553,7 +689,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 69:
+         case 86:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -561,7 +697,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 70:
+         case 87:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_modifier(&current_match, result, get_string("modifier"));
@@ -569,7 +705,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_modifier(%s)\n", get_string("modifier"));
 #endif
              break;
-         case 71:
+         case 88:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_position(&current_match, result, get_string("position"));
@@ -577,7 +713,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
 #endif
              break;
-         case 72:
+         case 89:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_position(&current_match, result, get_string("position"));
@@ -585,7 +721,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_position(%s)\n", get_string("position"));
 #endif
              break;
-         case 73:
+         case 90:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_color_single(&current_match, result, get_string("colorclass"), get_string("color"));
@@ -593,7 +729,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_color_single(%s, %s)\n", get_string("colorclass"), get_string("color"));
 #endif
              break;
-         case 74:
+         case 91:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_fake_outputs(&current_match, result, get_string("outputs"));
@@ -601,7 +737,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_fake_outputs(%s)\n", get_string("outputs"));
 #endif
              break;
-         case 75:
+         case 92:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_no_focus(&current_match, result);
@@ -609,7 +745,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_no_focus()\n");
 #endif
              break;
-         case 76:
+         case 93:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_verbose(&current_match, result, get_string("value"));
@@ -617,7 +753,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_verbose(%s)\n", get_string("value"));
 #endif
              break;
-         case 77:
+         case 94:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_binding(&current_match, result, get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
@@ -625,7 +761,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_binding(%s, %s, %s, %s, %s, %s, %s, %s)\n", get_string("bindtype"), get_string("modifiers"), get_string("key"), get_string("release"), get_string("border"), get_string("whole_window"), get_string("exclude_titlebar"), get_string("command"));
 #endif
              break;
-         case 78:
+         case 95:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_output(&current_match, result, get_string("output"));
@@ -633,16 +769,16 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_output(%s)\n", get_string("output"));
 #endif
              break;
-         case 79:
+         case 96:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 27);
+             cfg_criteria_init(&current_match, result, 29);
 #else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 27);
-       cfg_criteria_init(&current_match, result, 27);
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 29);
+       cfg_criteria_init(&current_match, result, 29);
 #endif
              break;
-         case 80:
+         case 97:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_ipc_socket(&current_match, result, get_string("path"));
@@ -650,23 +786,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_ipc_socket(%s)\n", get_string("path"));
 #endif
              break;
-         case 81:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_new_window(&current_match, result, get_string("windowtype"), get_string("border"), -1);
-#else
-           fprintf(stderr, "cfg_new_window(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
-#endif
-             break;
-         case 82:
-             result->next_state = INITIAL;
-#ifndef TEST_PARSER
-             cfg_new_window(&current_match, result, get_string("windowtype"), get_string("border"), -1);
-#else
-           fprintf(stderr, "cfg_new_window(%s, %s, %d)\n", get_string("windowtype"), get_string("border"), -1);
-#endif
-             break;
-         case 83:
+         case 98:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_show_marks(&current_match, result, get_string("value"));
@@ -674,7 +794,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_show_marks(%s)\n", get_string("value"));
 #endif
              break;
-         case 84:
+         case 99:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_start(&current_match, result);
@@ -682,7 +802,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_start()\n");
 #endif
              break;
-         case 85:
+         case 100:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_font(&current_match, result, get_string("font"));
@@ -690,7 +810,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_font(%s)\n", get_string("font"));
 #endif
              break;
-         case 86:
+         case 101:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_mode(&current_match, result, get_string("mode"));
@@ -698,7 +818,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
-         case 87:
+         case 102:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_mode(&current_match, result, get_string("mode"));
@@ -706,7 +826,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
-         case 88:
+         case 103:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_mode(&current_match, result, get_string("mode"));
@@ -714,7 +834,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_mode(%s)\n", get_string("mode"));
 #endif
              break;
-         case 89:
+         case 104:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
@@ -723,7 +843,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
 #endif
              break;
-         case 90:
+         case 105:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
              cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
@@ -732,7 +852,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_add(&current_match, result, get_string("ctype"), NULL);
 #endif
              break;
-         case 91:
+         case 106:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_criteria_pop_state(&current_match, result);
@@ -741,7 +861,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
        cfg_criteria_pop_state(&current_match, result);
 #endif
              break;
-         case 92:
+         case 107:
              result->next_state = MODEBRACE;
 #ifndef TEST_PARSER
              cfg_enter_mode(&current_match, result, get_string("pango_markup"), get_string("modename"));
@@ -749,25 +869,25 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_enter_mode(%s, %s)\n", get_string("pango_markup"), get_string("modename"));
 #endif
              break;
-         case 93:
+         case 108:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 60);
+             cfg_criteria_init(&current_match, result, 64);
 #else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 60);
-       cfg_criteria_init(&current_match, result, 60);
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 64);
+       cfg_criteria_init(&current_match, result, 64);
 #endif
              break;
-         case 94:
+         case 109:
              result->next_state = CRITERIA;
 #ifndef TEST_PARSER
-             cfg_criteria_init(&current_match, result, 33);
+             cfg_criteria_init(&current_match, result, 34);
 #else
-           fprintf(stderr, "cfg_criteria_init(%d)\n", 33);
-       cfg_criteria_init(&current_match, result, 33);
+           fprintf(stderr, "cfg_criteria_init(%d)\n", 34);
+       cfg_criteria_init(&current_match, result, 34);
 #endif
              break;
-         case 95:
+         case 110:
              result->next_state = BAR;
 #ifndef TEST_PARSER
              cfg_bar_id(&current_match, result, get_string("bar_id"));
@@ -775,7 +895,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_bar_id(%s)\n", get_string("bar_id"));
 #endif
              break;
-         case 96:
+         case 111:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_exec(&current_match, result, get_string("exectype"), get_string("no_startup_id"), get_string("command"));
@@ -783,7 +903,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_exec(%s, %s, %s)\n", get_string("exectype"), get_string("no_startup_id"), get_string("command"));
 #endif
              break;
-         case 97:
+         case 112:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_font(&current_match, result, get_string("font"));
@@ -791,7 +911,7 @@ static void GENERATED_call(const int call_identifier, struct ConfigResultIR *res
            fprintf(stderr, "cfg_font(%s)\n", get_string("font"));
 #endif
              break;
-         case 98:
+         case 113:
              result->next_state = INITIAL;
 #ifndef TEST_PARSER
              cfg_bar_finish(&current_match, result);
